@@ -8,7 +8,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
@@ -1873,7 +1872,7 @@ xapp_status_icon_set_primary_menu (XAppStatusIcon *icon,
 
     g_clear_object (&icon->priv->primary_menu);
 
-    DEBUG ("set_primary_menu: %p", menu);
+    DEBUG ("%s: %p", icon->priv->name, menu);
 
     if (menu)
     {
@@ -1925,7 +1924,7 @@ xapp_status_icon_set_secondary_menu (XAppStatusIcon *icon,
 
     g_clear_object (&icon->priv->secondary_menu);
 
-    DEBUG ("set_secondary_menu: %p", menu);
+    DEBUG ("%s: %p", icon->priv->name, menu);
 
     if (menu)
     {
